@@ -1,7 +1,7 @@
 import cro_validate.classes.definition_classes as Definitions
 import cro_validate.classes.util_classes as Utils
 from cro_validate.enum import DataType, ValidationMode
-
+import cro_validate.util.definition_util as DefinitionUtil
 
 def get(definition_or_name, version=Utils.Empty):
 	"""
@@ -237,5 +237,28 @@ def instantiate(
 	return result
 
 
+def recurse_definition(
+			definition,
+			fqn,
+			value,
+			cb,
+			case_sensitive=True,
+			ignore_unknown_inputs=False,
+			version=Utils.Empty,
+			**kw
+		):
+	return DefinitionUtil.recurse_definition(
+				definition,
+				fqn,
+				None,
+				None,
+				value,
+				cb,
+				case_sensitive,
+				ignore_unknown_inputs,
+				version,
+				**kw
+			)
+
 def clear():
-	Definitions.Index.clear()
+	Definitions.Index.clear()
\ No newline at end of file
